
## Data Packages

| Integrated Package                                       | Source  | Activated Component                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               | Associated Securitymaster Attribute                                                                                                                                                                                                                  | Note |
|----------------------------------------------------------|---------| |------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------| --- |
| CIQ Alpha Factor Library                                 | S&P     | [`prismstudio.precalculated.alpha_factor_library`](<#prismstudio.precalculated.alpha_factor_library>)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             | CIQ tradingitemid <br> CIQ securityid <br> CIQ companyid                                                                                                                                                                                             |
| CIQ Company Intelligence, Product, Business Relationship | S&P     | [`prismstudio.company.description`](<#prismstudio.company.description>) <br> [`prismstudio.company.competitor`](<#prismstudio.company.competitor>) <br> [`prismstudio.company.product`](<#prismstudio.reference.product>) <br> [`prismstudio.company.relationship`](<#prismstudio.reference.relationship>)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        | CIQ tradingitemid <br> CIQ securityid <br> CIQ companyid                                                                                                                                                                                             |
| CIQ Estimate Consensus & Revision Add-On                 | S&P     | [`prismstudio.estimate.actual`](<#prismstudio.estimate.actual>) <br> [`prismstudio.estimate.consensus`](<#prismstudio.estimate.consensus>) <br> [`prismstudio.estimate.guidance`](<#prismstudio.estimate.guidance>) <br> [`prismstudio.estimate.revision`](<#prismstudio.estimate.revision>) <br> [`prismstudio.estimate.surprise`](<#prismstudio.estimate.surprise>) <br> [`prismstudio.estimate.recommendation`](<#prismstudio.estimate.recommendation>) <br> [`prismstudio.estimate.industry`](<#prismstudio.estimate.industry>)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               | CIQ tradingitemid <br> CIQ securityid <br> CIQ companyid                                                                                                                                                                                             |
| CIQ Premium Financials                                   | S&P     | [`prismstudio.financial.balance_sheet`](<#prismstudio.financial.balance_sheet>) <br> [`prismstudio.financial.cash_flow`](<#prismstudio.financial.cash_flow>) <br> [`prismstudio.financial.dps`](<#prismstudio.financial.dps>) <br> [`prismstudio.financial.eps`](<#prismstudio.financial.eps>) <br> [`prismstudio.financial.income_statement`](<#prismstudio.financial.income_statement>) <br> [`prismstudio.financial.segment`](<#prismstudio.financial.segment>) <br> [`prismstudio.financial.ratio`](<#prismstudio.financial.ratio>) <br> [`prismstudio.financial.commitment`](<#prismstudio.financial.commitment>) <br> [`prismstudio.financial.option`](<#prismstudio.financial.option>) <br> [`prismstudio.financial.pension`](<#prismstudio.financial.pension>) <br> [`prismstudio.financial.industry`](<#prismstudio.financial.industry>)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 | CIQ tradingitemid <br> CIQ securityid <br> CIQ companyid                                                                                                                                                                                             |
| CIQ Transactions M&A                                     | S&P     | [`prismstudio.transaction.ma`](<#pvrismstudio.transaction.ma>) <br> [`prismstudio.transaction.buyback`](<#prismstudio.transaction.buyback>)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       | CIQ tradingitemid <br> CIQ securityid <br> CIQ companyid                                                                                                                                                                                             |
| CIQ Market                                               | S&P     | [`prismstudio.market.high`](<#prismstudio.market.high>) <br> [`prismstudio.market.low`](<#prismstudio.market.low>) <br> [`prismstudio.market.open`](<#prismstudio.market.open>) <br> [`prismstudio.market.close`](<#prismstudio.market.close>) <br> [`prismstudio.market.ask`](<#prismstudio.market.ask>) <br> [`prismstudio.market.bid`](<#prismstudio.market.bid>) <br> [`prismstudio.market.volume`](<#prismstudio.market.volume>) <br> [`prismstudio.market.vwap`](<#prismstudio.market.vwap>) <br> [`prismstudio.market.market_cap`](<#prismstudio.market.market_cap>) <br> [`prismstudio.market.shares_outstanding`](<#prismstudio.market.shares_outstanding>) <br> [`prismstudio.market.enterprise_value`](<#prismstudio.market.enterprise_value>) <br> [`prismstudio.market.diluted_market_cap`](<#prismstudio.market.diluted_market_cap>) <br> [`prismstudio.market.dividend`](<#prismstudio.financial.eps>) <br> [`prismstudio.market.dividend_adjustment_factor`](<#prismstudio.market.dividend_adjustment_factor>) <br> [`prismstudio.market.split`](<#prismstudio.market.split>) <br> [`prismstudio.market.split_adjustment_factor`](<#prismstudio.market.split_adjustment_factor>) <br> [`prismstudio.market.exchange_rate`](<#prismstudio.market.exchange_rate>) <br> [`prismstudio.market.totalreturnindex`](<#prismstudio.market.totalreturnindex>) <br> [`prismstudio.market.beta`](<#prismstudio.market.beta>) | CIQ tradingitemid <br> CIQ securityid <br> CIQ companyid                                                                                                                                                                                             |
| MI Integrated Market                                     | S&P     | [`prismstudio.market.high`](<#prismstudio.market.high>) <br> [`prismstudio.market.low`](<#prismstudio.market.low>) <br> [`prismstudio.market.open`](<#prismstudio.market.open>) <br> [`prismstudio.market.close`](<#prismstudio.market.close>) <br> [`prismstudio.market.ask`](<#prismstudio.market.ask>) <br> [`prismstudio.market.bid`](<#prismstudio.market.bid>) <br> [`prismstudio.market.volume`](<#prismstudio.market.volume>)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             | CIQ tradingitemid <br> CIQ securityid <br> CIQ companyid                                                                                                                                                                                             |
| Compustat                                                | S&P     | [`prismstudio.market.high`](<#prismstudio.market.high>) <br> [`prismstudio.market.low`](<#prismstudio.market.low>) <br> [`prismstudio.market.open`](<#prismstudio.market.open>) <br> [`prismstudio.market.close`](<#prismstudio.market.close>) <br> [`prismstudio.market.volume`](<#prismstudio.market.volume>) <br> [`prismstudio.market.shares_outstanding`](<#prismstudio.market.shares_outstanding>) <br> [`prismstudio.market.dividend`](<#prismstudio.financial.eps>) <br> [`prismstudio.market.split`](<#prismstudio.market.split>) <br> [`prismstudio.market.split_adjustment_factor`](<#prismstudio.market.split_adjustment_factor>) <br> [`prismstudio.market.exchange_rate`](<#prismstudio.market.exchange_rate>) <br>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 | CS gvkey <br> CS gvkeyiid                                                                                                                                                                                                                            |
| IHS Markit Short Interest                                | S&P     | [`prismstudio.market.short_interest`](<#prismstudio.market.short_interest>)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       | CIQ tradingitemid <br> CIQ securityid <br> CIQ companyid                                                                                                                                                                                             |
| GICRS CUSIP                                              | S&P     | [`prismstudio.securitymaster.attribute`](<#prismstudio.estimate.segment>)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         | CUSIP                                                                                                                                                                                                                                                |
| GICRS SEDOL                                              | S&P     | [`prismstudio.securitymaster.attribute`](<#prismstudio.estimate.segment>)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         | SEDOL                                                                                                                                                                                                                                                |
| GICS History                                             | S&P     | [`prismstudio.securitymaster.attribute`](<#prismstudio.estimate.segment>)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         | GICS Sector <br> GICS Group <br> GICS Industry <br> GICS Sub-industry                                                                                                                                                                                |
| CIQ Key Developments                                     | S&P     | [`prismstudio.event.summary`](<#prismstudio.event.summary>)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       | CIQ tradingitemid <br> CIQ securityid <br> CIQ companyid                                                                                                                                                                                             |
| CIQ Transcripts                                          | S&P     | [`prismstudio.event.earnings_call`](<#prismstudio.event.earnings_call>)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           | CIQ tradingitemid <br> CIQ securityid <br> CIQ companyid                                                                                                                                                                                             |
| S&P Global ESG Scores                                    | S&P     | [`prismstudio.esg.overall`](<#prismstudio.esg.overall>) <br> [`prismstudio.esg.environmental`](<#prismstudio.esg.environmental>) <br> [`prismstudio.esg.social`](<#prismstudio.esg.social>) <br> [`prismstudio.esg.governance`](<#prismstudio.esg.governance>)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    | CIQ tradingitemid <br> CIQ securityid <br> CIQ companyid                                                                                                                                                                                             |
| Datastream 2                                             | LSEG    | [`prismstudio.market.high`](<#prismstudio.market.high>) <br> [`prismstudio.market.low`](<#prismstudio.market.low>) <br> [`prismstudio.market.open`](<#prismstudio.market.open>) <br> [`prismstudio.market.close`](<#prismstudio.market.close>) <br> [`prismstudio.market.ask`](<#prismstudio.market.ask>) <br> [`prismstudio.market.bid`](<#prismstudio.market.bid>) <br> [`prismstudio.market.volume`](<#prismstudio.market.volume>) <br> [`prismstudio.market.vwap`](<#prismstudio.market.vwap>) <br> [`prismstudio.market.market_cap`](<#prismstudio.market.market_cap>) <br> [`prismstudio.market.shares_outstanding`](<#prismstudio.market.shares_outstanding>) <br> [`prismstudio.market.dividend`](<#prismstudio.financial.eps>) <br> [`prismstudio.market.dividend_adjustment_factor`](<#prismstudio.market.dividend_adjustment_factor>) <br> [`prismstudio.market.split`](<#prismstudio.market.split>) <br> [`prismstudio.market.split_adjustment_factor`](<#prismstudio.market.split_adjustment_factor>) <br> [`prismstudio.market.exchange_rate`](<#prismstudio.market.exchange_rate>) <br> [`prismstudio.market.totalreturnindex`](<#prismstudio.market.totalreturnindex>) <br> [`prismstudio.market.beta`](<#prismstudio.market.beta>)                                                                                                                                                                               | DS2 dsinfocode <br> DS2 dseccode <br> DS2 dscmpycode <br> DS2 exchintcode                                                                                                                                                                            |
| Datastream 2 Index                                       | LSEG    | [`prismstudio.index.level`](<#prismstudio.index.level>) <br> [`prismstudio.index.share`](<#prismstudio.index.share>) <br> [`prismstudio.index.weight`](<#prismstudio.index.weight>)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               | DS2 dsinfocode <br> DS2 dseccode <br> DS2 dscmpycode <br> DS2 exchintcode                                                                                                                                                                                         |
| Datastream Economics                                     | LSEG    | [`prismstudio.economics.economics`](<#prismstudio.economics.economics>)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   |                                                                                                                                                                                      |
| LSEG Financials                                          | LSEG    | [`prismstudio.financial.balance_sheet`](<#prismstudio.financial.balance_sheet>) <br> [`prismstudio.financial.cash_flow`](<#prismstudio.financial.cash_flow>) <br> [`prismstudio.financial.dps`](<#prismstudio.financial.dps>) <br> [`prismstudio.financial.eps`](<#prismstudio.financial.eps>) <br> [`prismstudio.financial.income_statement`](<#prismstudio.financial.income_statement>) <br> [`prismstudio.financial.segment`](<#prismstudio.financial.segment>) <br> [`prismstudio.financial.ratio`](<#prismstudio.financial.ratio>) <br> [`prismstudio.financial.commitment`](<#prismstudio.financial.commitment>) <br> [`prismstudio.financial.option`](<#prismstudio.financial.option>) <br> [`prismstudio.financial.pension`](<#prismstudio.financial.pension>) <br> [`prismstudio.financial.industry`](<#prismstudio.financial.industry>)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 | RKD issuecode <br> RKD cmpcode                                                                                                                                                                                                                       ||
| LSEG Significant Development                             | LSEG    | [`prismstudio.event.summary`](<#prismstudio.event.summary>)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       | RKD issuecode <br> RKD cmpcode                                                                                                                                                                                                                       ||
| LSEG Business Description                                | LSEG    | [`prismstudio.company.description`](<#prismstudio.company.description>)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           | RKD issuecode <br> RKD cmpcode                                                                                                                                                                                                                       ||
| LSEG Competitors                                         | LSEG    | [`prismstudio.company.competitor`](<#prismstudio.company.competitor>)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             | RKD issuecode <br> RKD cmpcode                                                                                                                                                                                                                       ||
| LSEG ESG V2                                              | LSEG    | [`prismstudio.esg.overall`](<#prismstudio.esg.overall>) <br> [`prismstudio.esg.environmental`](<#prismstudio.esg.environmental>) <br> [`prismstudio.esg.social`](<#prismstudio.esg.social>) <br> [`prismstudio.esg.governance`](<#prismstudio.esg.governance>) <br> [`prismstudio.esg.diversity`](<#prismstudio.esg.diversity>)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   | OrgPermID                                                                                                                                                                                             |
| I/B/E/S Estimates V2                                     | LSEG    | [`prismstudio.estimate.actual`](<#prismstudio.estimate.actual>) <br> [`prismstudio.estimate.consensus`](<#prismstudio.estimate.consensus>) <br> [`prismstudio.estimate.guidance`](<#prismstudio.estimate.guidance>) <br> [`prismstudio.estimate.revision`](<#prismstudio.estimate.revision>) <br> [`prismstudio.estimate.surprise`](<#prismstudio.estimate.surprise>) <br> [`prismstudio.estimate.recommendation`](<#prismstudio.estimate.recommendation>) <br> [`prismstudio.estimate.industry`](<#prismstudio.estimate.industry>) <br> [`prismstudio.estimate.segment`](<#prismstudio.estimate.segment>)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        | <br> IBES Security EstPermID <br> IBES Company EstPermID <br> IBES Ticker                                                                                                                                                                            |
| Starmine                                                 | LSEG    | [`prismstudio.precalculated.starmine`](<#prismstudio.precalculated.starmine>)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     | CIQ tradingitemid <br> CIQ securityid <br> CIQ companyid                                                                                                                                                                                             |
| Reference Data Convergence                               | LSEG    | [`prismstudio.securitymaster.attribute`](<#prismstudio.estimate.segment>)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         | RIC <br> SIC <br> TRBC Activity <br> TRBC Industry <br> TRBC Industry Group <br> TRBC Business Sector <br> TRBC Economic Sector <br> GICS Subind <br> GICS Industry <br> GICS Group <br> GICS Sector <br> RDC quoteid <br> RDC instrid <br> RDC orgid |
| FactSet Estimates Consensus                              | FactSet | [`prismstudio.estimate.actual`](<#prismstudio.estimate.actual>) <br> [`prismstudio.estimate.consensus`](<#prismstudio.estimate.consensus>) <br> [`prismstudio.estimate.guidance`](<#prismstudio.estimate.guidance>) <br> [`prismstudio.estimate.revision`](<#prismstudio.estimate.revision>) <br> [`prismstudio.estimate.surprise`](<#prismstudio.estimate.surprise>) <br> [`prismstudio.estimate.recommendation`](<#prismstudio.estimate.recommendation>) <br> [`prismstudio.estimate.industry`](<#prismstudio.estimate.industry>)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               | FS fsym_listingid <br> FS fsym_regionalid <br> FS fsym_securityid <br> FS fsym_entityid                                                                                                                                                              |
| FactSet Fundamentals                                     | FactSet | [`prismstudio.financial.income_statement`](<#prismstudio.financial.income_statement>) <br> [`prismstudio.financial.balance_sheet`](<#prismstudio.financial.balance_sheet>) <br> [`prismstudio.financial.cash_flow`](<#prismstudio.financial.cash_flow>) <br> [`prismstudio.financial.eps`](<#prismstudio.financial.eps>) <br> [`prismstudio.financial.dps`](<#prismstudio.financial.dps>) <br> [`prismstudio.financial.commitment`](<#prismstudio.financial.commitment>) <br> [`prismstudio.financial.pension`](<#prismstudio.financial.pension>) <br>[`prismstudio.financial.segment`](<#prismstudio.financial.segment>) <br>  [`prismstudio.financial.industry`](<#prismstudio.financial.industry>)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             | FS fsym_listingid <br> FS fsym_regionalid <br> FS fsym_securityid <br> FS fsym_entityid                                                                                                                                                              |
| TOPIX Index                                              | S&P     | [`prismstudio.index.level`](<#prismstudio.index.level>) <br> [`prismstudio.index.share`](<#prismstudio.index.share>) <br> [`prismstudio.index.weight`](<#prismstudio.index.weight>)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               | CIQ tradingitemid <br> CIQ securityid <br> CIQ companyid                                                                                                                                                                                             |
| Euronext Index                                           | S&P     | [`prismstudio.index.level`](<#prismstudio.index.level>) <br> [`prismstudio.index.share`](<#prismstudio.index.share>) <br> [`prismstudio.index.weight`](<#prismstudio.index.weight>)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               | CIQ tradingitemid <br> CIQ securityid <br> CIQ companyid                                                                                                                                                                                             |
| TSX Index                                                | S&P     | [`prismstudio.index.level`](<#prismstudio.index.level>) <br> [`prismstudio.index.share`](<#prismstudio.index.share>) <br> [`prismstudio.index.weight`](<#prismstudio.index.weight>)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               | CIQ tradingitemid <br> CIQ securityid <br> CIQ companyid                                                                                                                                                                                             |
| ASX Index                                                | S&P     | [`prismstudio.index.level`](<#prismstudio.index.level>) <br> [`prismstudio.index.share`](<#prismstudio.index.share>) <br> [`prismstudio.index.weight`](<#prismstudio.index.weight>)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               | CIQ tradingitemid <br> CIQ securityid <br> CIQ companyid                                                                                                                                                                                             |
| S&P US Index                                             | S&P     | [`prismstudio.index.level`](<#prismstudio.index.level>) <br> [`prismstudio.index.share`](<#prismstudio.index.share>) <br> [`prismstudio.index.weight`](<#prismstudio.index.weight>)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               | CIQ tradingitemid <br> CIQ securityid <br> CIQ companyid                                                                                                                                                                                             |
| S&P Global Index                                         | S&P     | [`prismstudio.index.level`](<#prismstudio.index.level>) <br> [`prismstudio.index.share`](<#prismstudio.index.share>) <br> [`prismstudio.index.weight`](<#prismstudio.index.weight>)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               | CIQ tradingitemid <br> CIQ securityid <br> CIQ companyid                                                                                                                                                                                             |
| S&P Europe Index                                         | S&P     | [`prismstudio.index.level`](<#prismstudio.index.level>) <br> [`prismstudio.index.share`](<#prismstudio.index.share>) <br> [`prismstudio.index.weight`](<#prismstudio.index.weight>)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               | CIQ tradingitemid <br> CIQ securityid <br> CIQ companyid                                                                                                                                                                                             |
| SPDJ BMI World                                           | S&P     | [`prismstudio.index.level`](<#prismstudio.index.level>) <br> [`prismstudio.index.share`](<#prismstudio.index.share>) <br> [`prismstudio.index.weight`](<#prismstudio.index.weight>)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               | CIQ tradingitemid <br> CIQ securityid <br> CIQ companyid                                                                                                                                                                                             |
| SPDJ BMI Emerging                                        | S&P     | [`prismstudio.index.level`](<#prismstudio.index.level>) <br> [`prismstudio.index.share`](<#prismstudio.index.share>) <br> [`prismstudio.index.weight`](<#prismstudio.index.weight>)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               | CIQ tradingitemid <br> CIQ securityid <br> CIQ companyid                                                                                                                                                                                             |
| SPDJ BMI Global                                          | S&P     | [`prismstudio.index.level`](<#prismstudio.index.level>) <br> [`prismstudio.index.share`](<#prismstudio.index.share>) <br> [`prismstudio.index.weight`](<#prismstudio.index.weight>)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               | CIQ tradingitemid <br> CIQ securityid <br> CIQ companyid                                                                                                                                                                                             |
| Russell US Index                                         | LSEG    | [`prismstudio.index.level`](<#prismstudio.index.level>) <br> [`prismstudio.index.share`](<#prismstudio.index.share>) <br> [`prismstudio.index.weight`](<#prismstudio.index.weight>)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               | CIQ tradingitemid <br> CIQ securityid <br> CIQ companyid                                                                                                                                                                                             |
| Russell Global Index                                     | LSEG    | [`prismstudio.index.level`](<#prismstudio.index.level>) <br> [`prismstudio.index.share`](<#prismstudio.index.share>) <br> [`prismstudio.index.weight`](<#prismstudio.index.weight>)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               | CIQ tradingitemid <br> CIQ securityid <br> CIQ companyid                                                                                                                                                                                             |
| FTSE Index                                               | LSEG    | [`prismstudio.index.level`](<#prismstudio.index.level>) <br> [`prismstudio.index.share`](<#prismstudio.index.share>) <br> [`prismstudio.index.weight`](<#prismstudio.index.weight>)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               | CIQ tradingitemid <br> CIQ securityid <br> CIQ companyid                                                                                                                                                                                             |




 